@@ -22,7 +22,10 @@ import weakref
 import matplotlib
 matplotlib.use('WXAgg')
 import numpy as NumPy
-from matplotlib.axes import _process_plot_var_args
+try:
+    from matplotlib.axes import _process_plot_var_args
+except:
+    from matplotlib.axes._base import _process_plot_var_args
 from matplotlib.backend_bases import FigureCanvasBase
 from matplotlib.backends.backend_agg import FigureCanvasAgg, RendererAgg
 from matplotlib.backends.backend_wxagg import FigureCanvasWxAgg
@@ -1124,7 +1127,7 @@ class PlotPanel(FigureCanvasWxAgg):
         # find the toplevel parent window and register an activation event
         # handler that is keyed to the id of this PlotPanel
         topwin = toplevel_parent_of_window(self)
-        topwin.Connect(self.GetId(),-1, wx.wxEVT_ACTIVATE, self.OnActivate)
+        topwin.Connect(self.GetId(), -1, wx.wxEVT_ACTIVATE, self.OnActivate)
 
         wx.EVT_ERASE_BACKGROUND(self, self.OnEraseBackground)
         wx.EVT_WINDOW_DESTROY(self, self.OnDestroy)
@@ -1422,7 +1425,7 @@ class PlotFrame(wx.Frame):
         fileName = wx.FileSelector('Save Plot', default_extension='png',
             wildcard=('Portable Network Graphics (*.png)|*.png|'
                 + 'Encapsulated Postscript (*.eps)|*.eps|All files (*.*)|*.*'),
-            parent=self, flags=wx.SAVE|wx.OVERWRITE_PROMPT)
+            parent=self, flags=wx.FD_SAVE|wx.FD_OVERWRITE_PROMPT)
 
         if not fileName:
             return
