@@ -50,7 +50,7 @@ def german2Float(s):
 	if len(splitCommas)==1:#no commas found, treat as regular float
 		return(float(s))
 	splitPoints=s.split('.')
-	if len(splitPoints)==1:#no points found
+	if len(splitPoints)==1:#no points found, treat as "german" float
 		return(float(s.replace(",",".")))
 	if len(splitCommas[-1])>len(splitPoints[-1]):
 		s=""
