@@ -302,6 +302,23 @@ class specmate_fitWindow(fitWindow_template):
 			self.setPeakCtrls()
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
+	
+        #--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+	def _onPeakTextChanged(self, event):  
+		self.readPeakCtrls()
+		self.writePeakData()
+	#--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+
+        #--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+	def _onIncludeShape(self, event):  
+            if self.parent.backend.peakSpectra[self.peak].peakType=="gaussian" or self.parent.backend.peakSpectra[self.peak].peakType=="lorentzian":
+                pass
+	#--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
 	def _onReferenceSelected(self, event):  
@@ -314,8 +331,21 @@ class specmate_fitWindow(fitWindow_template):
 			self.setRefCtrls()
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
-	
-	
+
+	#--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+        def _onIncludeRef(self,event):
+		self.checkboxIncludeCoeff.SetValue(self.checkboxIncludeReference.GetValue())
+        #--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+
+	#--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+        def _onIncludeRefCoeff(self,event):
+		self.checkboxIncludeReference.SetValue(self.checkboxIncludeCoeff.GetValue())
+        #--------------------------------------------------------------------------------
+	#--------------------------------------------------------------------------------
+        	
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
 	def receiver(self,x,y):
