@@ -36,7 +36,7 @@ except:
 	sys.exit(1)
 
 #try:
-#	import wxmpl
+#import wxmpl
 #except:
 #	print "It seems that you don't have wxmpl installed, I'll try to use a copy distributed along with SpecMate."
 import copy_of_wxmpl as wxmpl
@@ -478,11 +478,36 @@ class MainWindow_windowContents(MainWindow_helperFunctions):
                 displayMM=wx.DisplaySizeMM()
 		displayInchX=displayMM[0]/25.4
 		displayInchY=displayMM[1]/25.4
-                ppiX=int(displayPX[0]/displayInchX)
-                ppiY=int(displayPX[1]/displayInchY)
+                ppiX=int(round(displayPX[0]/displayInchX))
+                ppiY=int(round(displayPX[1]/displayInchY))
                 ppi=min(ppiX,ppiY)
+                #-------------------------------------------------
+                # This here is a workaround for multiple display:
+                # We simply use the smallest one and hope that the ppi were determined correctly before
+                #-------------------------------------------------
+                if wx.Display.GetCount()>1:
+                    #warnings.warn("Multiple Displays found!")
+                    sizeX=wx.Display(0).GetGeometry().GetSize()[0]
+                    sizeY=wx.Display(0).GetGeometry().GetSize()[1]
+                    for i in xrange(1,wx.Display.GetCount()):
+                        if wx.Display(i).GetGeometry().GetSize()[0]<sizeX:
+                            sizeX=wx.Display(i).GetGeometry().GetSize()[0]
+                        if wx.Display(i).GetGeometry().GetSize()[1]<sizeY:
+                            sizeY=wx.Display(i).GetGeometry().GetSize()[1]
+                    displayInchX*=sizeX
+                    displayInchX/=displayPX[0]
+                    displayInchY*=sizeY
+                    displayInchY/=displayPX[1]
+                #-------------------------------------------------
+                #-------------------------------------------------
 
-                self.plotPanel	=	wxmpl.PlotPanel(self,-1,size=(displayInchX*0.75,displayInchX*0.75*0.617),dpi=ppi)
+                initialSizeX=displayInchX*0.75
+                initialSizeY=initialSizeX*0.617
+                if initialSizeY>displayInchY*0.85:
+                    initialSizeY=displayInchY*0.85
+                    initialSizeX=initialSizeY/0.617
+
+                self.plotPanel	=	wxmpl.PlotPanel(self,-1,size=(initialSizeX,initialSizeY),dpi=ppi)
 		wxmpl.EVT_POINT(self.plotPanel, -1, self._handleMouseClicks)
 	        self.sizer = wx.BoxSizer(wx.VERTICAL)
 	        self.sizer.Add(self.plotPanel, 1, wx.EXPAND, 5)
