@@ -46,7 +46,7 @@ except:
 
 from specmate_datasets import specmate_singleDataset
 #from specmate_menubar import specmate_menubar
-from specmate_globals import *
+#from specmate_globals import *
 from specmate_settings import *
 #----------------------------------------------------------------------------
 #----------------------------------------------------------------------------
@@ -481,6 +481,8 @@ class specmate_refWindow(wx.Frame):
 			self.name.append(each.name)
 		self._initFrameContents()
 		self.SetTitle(title+' <'+self.parent.backend.specData.name+'>')
+                self.scroll = wx.ScrolledWindow(self, id)
+                self.scroll.SetScrollbars(1, 1, 2000, 1500)
 		self.Show()
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
